;; Generated package description from xah-fly-keys.el  -*- no-byte-compile: t -*-
(define-package "xah-fly-keys" "17.23.20220910102958" "ergonomic modal keybinding minor mode." '((emacs "24.1")) :commit "fa460b475df78408f2a5a8acee2b0284fb287aba" :authors '(("Xah Lee ( http://xahlee.info/ )")) :maintainer '("Xah Lee" . "xah@xahlee.org") :keywords '("convenience" "emulations" "vim" "ergoemacs") :url "http://xahlee.info/emacs/misc/xah-fly-keys.html")
